@@ -1960,7 +1960,7 @@ ch * find_outfile(ch *infile, double basetime)
    if (pp) *pp = 0;
    bcc = strlen(basename);
 
-   repl_Nstrs(infile,findpatt,XFCC," ","\\ ","\"","\\\"","'","\\'",0);           //  escapes for 'find' command
+   repl_Nstrs(infile,findpatt,XFCC," ","\\ ","\"","\\\"","'","\\'",null);        //  escapes for 'find' command
    pp = strrchr(findpatt,'/');                                                   //  search folder
    if (! pp) return 0;
    pp[1] = 0;
